- [ ] I'm reporting a bug, not asking for help
- [ ] I've looked at the [documentation](http://leaflet.github.io/Leaflet.draw/dist/reference-0.4.1.html) to make sure the behaviour is documented and expected
- [ ] I'm sure this is a Leaflet Draw code issue, not an issue with my own code nor with the framework I'm using (Cordova, Ionic, Angular, React…)
- [ ] I've searched through the issues to make sure it's not yet reported

----

## How to reproduce

- Leaflet version I'm using:
- Leaflet Draw version I'm using:
- Browser (with version) I'm using:
- OS/Platform (with version) I'm using:
- step 1
- step 2

## What behaviour I'm expecting and which behaviour I'm seeing

## Minimal example reproducing the issue

- [ ] this example is as simple as possible
- [ ] this example does not rely on any third party code

Using [jsfiddle](https://jsfiddle.net/ddproxy/mvp7hgou/) or another example site.